@@ -6,11 +6,12 @@ Usage:
                                   [--user=<user_name>] [--pass=<user_pass>]
                                   [--application=<okta_application>]
                                   [--role=<role_name>]
-                                  [--account=<account>]
+                                  [--account-alias=<account_alias>]
                                   [--duration=<duration_seconds>]
                                   [--key=<key>]
                                   [--factor=<factor>]
                                   [--silent] [--no-okta-cache] [--no-aws-cache]
+                                  [--target-shell=<target_shell>]
 
   aws-okta-processor -h | --help
   aws-okta-processor --version
@@ -26,11 +27,12 @@ Options:
   -o <okta_organization> --organization=<okta_organization>  Okta organization domain.
   -a <okta_application> --application=<okta_application>     Okta application url.
   -r <role_name> --role=<role_name>                          AWS role ARN.
-  -A <account> --account=<account>                           AWS account filter (uses wildcards).
+  -A <account> --account-alias=<account>                     AWS account alias filter (uses wildcards).
   -d <duration_seconds> --duration=<duration_seconds>        Duration of role session [default: 3600].
   -k <key> --key=<key>                                       Key used for generating and accessing cache.
   -f <factor> --factor=<factor>                              Factor type for MFA.
   -s --silent                                                Run silently.
+  --target-shell <target_shell>                              Target shell to output the export command.
 
 Help:
   For help using this tool, please reach out to our Slack channel:
